@@ -1,6 +1,7 @@
 /*
+** Copyright (C) 2014 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2010-2013 Sourcefire, Inc.
-** Author: Michael R. Altizer <maltizer@sourcefire.com>
+** Author: Michael R. Altizer <mialtize@cisco.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -24,7 +25,7 @@
 #include <stdio.h>
 #include <daq_common.h>
 
-#define DAQ_VERSION_2
+#define DAQ_VERSION 7
 
 /* Definition of the structures returned by daq_get_module_list(). */
 typedef struct {
@@ -33,6 +34,10 @@ typedef struct {
     uint32_t type;      /* Module capabilities */
 } DAQ_Module_Info_t;
 
+/* Library version information functions. */
+DAQ_LINKAGE uint32_t daq_version_number(void);
+DAQ_LINKAGE const char *daq_version_string(void);
+
 /* Functions for loading, handling, and unloading DAQ modules. */
 DAQ_LINKAGE void daq_set_verbosity(int level);
 DAQ_LINKAGE int daq_load_modules(const char *module_dirs[]);
@@ -77,9 +82,12 @@ DAQ_LINKAGE uint32_t daq_get_capabilities(const DAQ_Module_t *module, void *hand
 DAQ_LINKAGE int daq_get_datalink_type(const DAQ_Module_t *module, void *handle);
 DAQ_LINKAGE const char *daq_get_error(const DAQ_Module_t *module, void *handle);
 DAQ_LINKAGE void daq_clear_error(const DAQ_Module_t *module, void *handle);
-DAQ_LINKAGE int daq_modify_flow(const DAQ_Module_t *module, void *handle, const DAQ_PktHdr_t *hdr, DAQ_ModFlow_t *modify);
+DAQ_LINKAGE int daq_modify_flow(const DAQ_Module_t *module, void *handle, const DAQ_PktHdr_t *hdr, const DAQ_ModFlow_t *modify);
+DAQ_LINKAGE int daq_query_flow(const DAQ_Module_t *module, void *handle, const DAQ_PktHdr_t *hdr, DAQ_QueryFlow_t *query);
 DAQ_LINKAGE int daq_hup_prep(const DAQ_Module_t *module, void *handle, void **new_config);
 DAQ_LINKAGE int daq_hup_apply(const DAQ_Module_t *module, void *handle, void *new_config, void **old_config);
 DAQ_LINKAGE int daq_hup_post(const DAQ_Module_t *module, void *handle, void *old_config);
+DAQ_LINKAGE int daq_dp_add_dc(const DAQ_Module_t *module, void *handle, const DAQ_PktHdr_t *hdr, DAQ_DP_key_t *dp_key,
+        const uint8_t *packet_data, DAQ_Data_Channel_Params_t *params);
 
 #endif /* _DAQ_H */
