@@ -22,10 +22,6 @@
  *
  *  Optimization module for tcpdump intermediate representation.
  */
-#ifndef lint
-static const char rcsid[] =
-    "@(#) $Header: //depot/firepower/daq-opensource/DAQ_2_0_7/sfbpf/sf_optimize.c#1 $ (LBL)";
-#endif
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
